# Changelog

## [0.0.34a1](https://github.com/OpenVoiceOS/ovos-utils/tree/0.0.34a1) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33...0.0.34a1)

**Fixed bugs:**

- Event Scheduler Interface tests [\#156](https://github.com/OpenVoiceOS/ovos-utils/pull/156) ([NeonDaniel](https://github.com/NeonDaniel))

**Merged pull requests:**

- Add unit test coverage for SkillApi [\#145](https://github.com/OpenVoiceOS/ovos-utils/pull/145) ([NeonDaniel](https://github.com/NeonDaniel))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
